.. py:currentmodule:: pydlm
		      
Installation
============
You can now get the package from `PyPI`::

  $ pip install pydlm

You can also get the latest from `github
<https://github.com/wwrechard/PyDLM>`_::

      $ git clone git@github.com:wwrechard/pydlm.git pydlm
      $ cd pydlm
      $ sudo python setup.py install

:mod:`pydlm` depends on the following modules,

* :mod:`numpy`      (for core functionality)
* :mod:`matplotlib` (for plotting results)
* :mod:`Sphinx`     (for generating documentation)
* :mod:`unittest`   (for tests)
